@@ -79,31 +79,27 @@ class IFS_explorer():
     color = "#E6E6FA"
 
     ##variables for the graphic part
-    window = Tk()
-    window.title("IFS Explorer")
-    window.geometry("1350x730")
-    window.resizable(0, 0)
-    radius_ = IntVar()
-    band_sticks = IntVar()
+    window = 0
+    radius_ = 0
+    band_sticks = 0
+    varla1 = 0
+    varlaflux = 0 
+    varla3 = 0
+    varla4 = 0
+    varlawave = 0
+    varla5 = 0
+    varla6 = 0
+    varla7 = 0
+    varla8 = 0
+    varla9 = 0
+    varla10 = 0
+    varla11 = 0
+    var = 0
+    var3 = 0
+    var3 = 0
+    sp1 = 0
     min_value_la = 0
     max_value_la = 0
-    varla1 = StringVar()
-    varlaflux = StringVar() 
-    varla3 = DoubleVar()
-    varla4 = DoubleVar()
-    varlawave = StringVar()
-    varla5 = IntVar()
-    varla6 = IntVar()
-    varla7 = StringVar()
-    varla8 = StringVar()
-    varla9 = StringVar()
-    varla10 = StringVar()
-    varla11 = DoubleVar()
-    var = IntVar() 
-    var.set(1)
-    var3 = StringVar()
-    var3 = StringVar()
-    sp1 = IntVar()
     
     ##graphic elements
     box_entry = 0
@@ -1277,6 +1273,8 @@ class IFS_explorer():
                      (self.flag_wave) = 0
                      (self.varla5).set(int(self.min_value_la))
                      (self.varla6).set(int(self.max_value_la))
+                     (self.varla3).set(0)
+                     (self.varla4).set(0)
                      filters_((self.name_f))
             except Exception as e: 
                    print(e)
@@ -1358,7 +1356,29 @@ class IFS_explorer():
         
             else:
                 MessageBox.showerror("Error!","Please, select a file") 
-            
+        self.window = Tk()
+        (self.window).title("IFS Explorer")
+        (self.window).geometry("1350x730")
+        (self.window).resizable(0, 0) 
+        (self.radius_) = IntVar()
+        (self.band_sticks) = IntVar()
+        (self.varla1) = StringVar()
+        (self.varlaflux) = StringVar() 
+        (self.varla3) = DoubleVar()
+        (self.varla4) = DoubleVar()
+        (self.varlawave) = StringVar()
+        (self.varla5) = IntVar()
+        (self.varla6) = IntVar()
+        (self.varla7)= StringVar()
+        (self.varla8) = StringVar()
+        (self.varla9) = StringVar()
+        (self.varla10) = StringVar()
+        (self.varla11) = DoubleVar()
+        (self.var) = IntVar() 
+        (self.var).set(1)
+        (self.var3) = StringVar()
+        (self.var3) = StringVar()
+        (self.sp1) = IntVar()
         print("Open the window....")
         get_cmaps()
         color = "#E6E6FA"
